pub unsafe extern "C" fn LLVMParseBitcode2(
MemBuf: LLVMMemoryBufferRef,
OutModule: *mut LLVMModuleRef,
) -> LLVMBool👎Deprecated since 221.0.0: Use of the global context is deprecated, use LLVMParseBitcodeInContext2 instead
Build a module from the bitcode in the specified memory buffer.
Returns the created module in OutModule, returns 0 on success.