pub unsafe extern "C" fn LLVMAppendBasicBlock(
Fn: LLVMValueRef,
Name: *const c_char,
) -> LLVMBasicBlockRef👎Deprecated since 221.0.0:
Use of the global context is deprecated, use LLVMAppendBasicBlockInContext instead.
pub unsafe extern "C" fn LLVMAppendBasicBlock(
Fn: LLVMValueRef,
Name: *const c_char,
) -> LLVMBasicBlockRefUse of the global context is deprecated, use LLVMAppendBasicBlockInContext instead.