pub unsafe extern "C" fn LLVMConstByteGetSExtValue(
ConstantVal: LLVMValueRef,
) -> c_longlongExpand description
Obtain the sign extended value for a byte constant value.
pub unsafe extern "C" fn LLVMConstByteGetSExtValue(
ConstantVal: LLVMValueRef,
) -> c_longlongObtain the sign extended value for a byte constant value.