pub unsafe extern "C" fn LLVMConstByteGetZExtValue(
ConstantVal: LLVMValueRef,
) -> c_ulonglongExpand description
Obtain the zero extended value for a byte constant value.
pub unsafe extern "C" fn LLVMConstByteGetZExtValue(
ConstantVal: LLVMValueRef,
) -> c_ulonglongObtain the zero extended value for a byte constant value.