pub unsafe extern "C" fn LLVMConstByteOfArbitraryPrecision(
ByteTy: LLVMTypeRef,
NumWords: c_uint,
Words: *const u64,
) -> LLVMValueRefExpand description
Obtain a constant value for a byte of arbitrary precision.
pub unsafe extern "C" fn LLVMConstByteOfArbitraryPrecision(
ByteTy: LLVMTypeRef,
NumWords: c_uint,
Words: *const u64,
) -> LLVMValueRefObtain a constant value for a byte of arbitrary precision.