pub unsafe extern "C" fn LLVMConstByteOfString(
ByteTy: LLVMTypeRef,
Text: *const c_char,
Radix: u8,
) -> LLVMValueRefExpand description
Obtain a constant value for a byte parsed from a string.
pub unsafe extern "C" fn LLVMConstByteOfString(
ByteTy: LLVMTypeRef,
Text: *const c_char,
Radix: u8,
) -> LLVMValueRefObtain a constant value for a byte parsed from a string.