pub unsafe extern "C" fn LLVMGetGlobalContext() -> LLVMContextRef👎Deprecated since 221.0.0:
Use of the global context is deprecated, create one using LLVMContextCreate instead
pub unsafe extern "C" fn LLVMGetGlobalContext() -> LLVMContextRefUse of the global context is deprecated, create one using LLVMContextCreate instead