LLVMSetSwitchCaseValue

Function LLVMSetSwitchCaseValue 

pub unsafe extern "C" fn LLVMSetSwitchCaseValue(
    SwitchInstr: LLVMValueRef,
    i: c_uint,
    CaseValue: LLVMValueRef,
)
Set the case value for a successor of a switch instruction. i corresponds to the successor index. The first successor is the default destination, so i must be greater than zero.

This only works on llvm::SwitchInst instructions.

See llvm::SwitchInst::CaseHandle::setValue().