Module ir_reader

Module ir_reader 

The IR reader

Functions

LLVMParseIRInContextDeprecated
Read LLVM IR from a memory buffer and convert it to an in-memory Module.
LLVMParseIRInContext2
Read LLVM IR from a memory buffer and convert it into an in-memory Module object. Returns 0 on success. Optionally returns a human-readable description of any errors that occurred during parsing IR. OutMessage must be disposed with LLVMDisposeMessage. The memory buffer is not consumed by this function. It is the responsibility of the caller to free it with LLVMDisposeMemoryBuffer.