Functions
- LLVM
OrcCreate ⚠Object Linking Layer With InProcess Memory Manager - Create a ObjectLinkingLayer instance using the standard JITLink InProcessMemoryManager for memory management.
- LLVM
OrcCreateRT ⚠Dyld Object Linking Layer WithMCJIT Memory Manager Like Callbacks - LLVM
OrcCreateRT ⚠Dyld Object Linking Layer With Section Memory Manager - LLVM
OrcCreateRT ⚠Dyld Object Linking Layer With Section Memory Manager Reserve Alloc - Create a RTDyldObjectLinkingLayer instance using the standard SectionMemoryManager for memory management. If ReserveAlloc is true then a contiguous range of memory will be reserved for each object file.
- LLVM
OrcRT ⚠Dyld Object Linking Layer RegisterJIT Event Listener