pub unsafe extern "C" fn LLVMIntPtrType(
TD: LLVMTargetDataRef,
) -> LLVMTypeRef👎Deprecated since 221.0.0:
Use of the global context is deprecated, use LLVMIntPtrTypeInContext instead.
pub unsafe extern "C" fn LLVMIntPtrType(
TD: LLVMTargetDataRef,
) -> LLVMTypeRefUse of the global context is deprecated, use LLVMIntPtrTypeInContext instead.