pub unsafe extern "C" fn LLVMConstFPFromBits(
Ty: LLVMTypeRef,
N: *const u64,
) -> LLVMValueRefExpand description
Obtain a constant for a floating point value from array of 64 bit values. The length of the array N must be ceildiv(bits, 64), where bits is the scalar size in bits of the floating-point type.