pub unsafe extern "C" fn LLVMGetOrInsertFunction(
M: LLVMModuleRef,
Name: *const c_char,
NameLen: size_t,
FunctionTy: LLVMTypeRef,
) -> LLVMValueRefExpand description
Obtain or insert a function into a module.
If a function with the specified name already exists in the module, it is returned. Otherwise, a new function is created in the module with the specified name and type and is returned.
The returned value corresponds to a llvm::Function instance.
See llvm::Module::getOrInsertFunction().