pub unsafe extern "C" fn LLVMGetSwitchCaseValue(
SwitchInstr: LLVMValueRef,
i: c_uint,
) -> LLVMValueRefExpand description
Obtain the case value for a successor of a switch instruction. i corresponds to the successor index. The first successor is the default destination, so i must be greater than zero.
This only works on llvm::SwitchInst instructions.
See llvm::SwitchInst::CaseHandle::getCaseValue().