pub unsafe extern "C" fn LLVMParseIRInContext2(
ContextRef: LLVMContextRef,
MemBuf: LLVMMemoryBufferRef,
OutM: *mut LLVMModuleRef,
OutMessage: *mut *mut c_char,
) -> LLVMBoolExpand description
Read LLVM IR from a memory buffer and convert it into an in-memory Module
object. Returns 0 on success.
Optionally returns a human-readable description of any errors that
occurred during parsing IR. OutMessage must be disposed with
LLVMDisposeMessage.
The memory buffer is not consumed by this function. It is the responsibility
of the caller to free it with LLVMDisposeMemoryBuffer.
See llvm::ParseIR().